This directory contains source data mapped to ontologies or web resources

###impc_mappings.yaml
Manually curated mappings of fields (codes, labels) to IRIs

###impc_procedures.json
procedures that cannot be web scraped as they are served as PDFs

###eco_map.yaml
Evidence Code to ECO curie map, manually generated
